from setuptools import setup

setup(name='allwhatspy',
    version='0.2.00.6',
    license='MIT License',
    author='Lucas Lourenço',
    long_description='Descontinuado. Utilize pip install -U allwhatspy-awp',
    long_description_content_type="text/markdown",
    author_email='dev.lucaslourenco@gmail.com',
    keywords='descontinuado',
    description=u'Descontinuado. Utilize pip install -U allwhatspy-awp',
    packages=['AllWhatsPy'],
    install_requires=['webdriver-manager', 'selenium', 'requests'],)